==> jc-1.4.0.tar.gz: gnu/xml/util/DoParse.h <==
// public final class gnu.xml.util.DoParse

// class file dependencies
// @dep_class d092700484a010be gnu_xml_util_DoParse
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_DoParse_H_
#define _JC_gnu_xml_util_DoParse_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_DoParse$sub_refs	_jc_gnu_xml_util_DoParse$sub_refs;
typedef struct _jc_gnu_xml_util_DoParse$sub_nonrefs	_jc_gnu_xml_util_DoParse$sub_nonrefs;
typedef struct _jc_gnu_xml_util_DoParse$refs	_jc_gnu_xml_util_DoParse$refs;
typedef struct _jc_gnu_xml_util_DoParse$nonrefs	_jc_gnu_xml_util_DoParse$nonrefs;
typedef struct _jc_gnu_xml_util_DoParse$object	_jc_gnu_xml_util_DoParse$object;

typedef struct _jc_gnu_xml_util_DoParse$fields_struct	_jc_gnu_xml_util_DoParse$fields_struct;
typedef const struct _jc_gnu_xml_util_DoParse$vmethods	_jc_gnu_xml_util_DoParse$vmethods;
typedef const struct _jc_gnu_xml_util_DoParse$vtable	_jc_gnu_xml_util_DoParse$vtable;
typedef const struct _jc_gnu_xml_util_DoParse$vtype	_jc_gnu_xml_util_DoParse$vtype;

// Class fields structure
struct _jc_gnu_xml_util_DoParse$fields_struct {
	struct _jc_org_xml_sax_SAXParseException$object	*fatal;
	jint	errorCount;
	jint	fatalCount;
};
extern _jc_gnu_xml_util_DoParse$fields_struct _jc_gnu_xml_util_DoParse$class_fields;

// Constructors
extern void _jc_gnu_xml_util_DoParse$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_DoParse$object *);

// Static methods
extern jint _jc_gnu_xml_util_DoParse$method$access__240$2268a8f72fbb4e6f(_jc_env *);
extern void _jc_gnu_xml_util_DoParse$method$access__241$c3d4e057b6cf95fa(_jc_env *, jint);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_DoParse$method$access__242$0654588957338362(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_org_xml_sax_SAXParseException$object *);
extern jint _jc_gnu_xml_util_DoParse$method$access__243$0b9a6e8ac62e1506(_jc_env *);
extern void _jc_gnu_xml_util_DoParse$method$access__244$18c3f443722fc029(_jc_env *, jint);
extern struct _jc_org_xml_sax_SAXParseException$object *_jc_gnu_xml_util_DoParse$method$access__245$0e6a98ae54f6c356(_jc_env *);
extern void _jc_gnu_xml_util_DoParse$method$access__246$a0c66610e253eb4e(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *);
extern jboolean _jc_gnu_xml_util_DoParse$method$hasValidator$3b7ba21255c43099(_jc_env *, struct _jc_object *);
extern void _jc_gnu_xml_util_DoParse$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_DoParse$method$printParseException$c8b5297bca28458c(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_org_xml_sax_SAXParseException$object *);

// Virtual methods structure
struct _jc_gnu_xml_util_DoParse$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_DoParse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_DoParse$vmethods	gnu_xml_util_DoParse;
};

// Vtype
struct _jc_gnu_xml_util_DoParse$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_DoParse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_DoParse$refs {
    _jc_gnu_xml_util_DoParse$sub_refs	gnu_xml_util_DoParse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_DoParse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_DoParse$sub_nonrefs	gnu_xml_util_DoParse;
};

// Object instance structure
struct _jc_gnu_xml_util_DoParse$object {
	_jc_gnu_xml_util_DoParse$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_DoParse$vtype	*vtype;
	_jc_gnu_xml_util_DoParse$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_DoParse$vtype _jc_gnu_xml_util_DoParse$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_DoParse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_DoParse$class_object;

#endif	/* _JC_gnu_xml_util_DoParse_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/DoParse.h <==
// public final class gnu.xml.util.DoParse

// class file dependencies
// @dep_class d092700484a010be gnu_xml_util_DoParse
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_util_DoParse_H_
#define _JC_gnu_xml_util_DoParse_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_SAXParseException$object;

// Typedefs
typedef struct _jc_gnu_xml_util_DoParse$sub_refs	_jc_gnu_xml_util_DoParse$sub_refs;
typedef struct _jc_gnu_xml_util_DoParse$sub_nonrefs	_jc_gnu_xml_util_DoParse$sub_nonrefs;
typedef struct _jc_gnu_xml_util_DoParse$refs	_jc_gnu_xml_util_DoParse$refs;
typedef struct _jc_gnu_xml_util_DoParse$nonrefs	_jc_gnu_xml_util_DoParse$nonrefs;
typedef struct _jc_gnu_xml_util_DoParse$object	_jc_gnu_xml_util_DoParse$object;

typedef struct _jc_gnu_xml_util_DoParse$fields_struct	_jc_gnu_xml_util_DoParse$fields_struct;
typedef const struct _jc_gnu_xml_util_DoParse$vmethods	_jc_gnu_xml_util_DoParse$vmethods;
typedef const struct _jc_gnu_xml_util_DoParse$vtable	_jc_gnu_xml_util_DoParse$vtable;
typedef const struct _jc_gnu_xml_util_DoParse$vtype	_jc_gnu_xml_util_DoParse$vtype;

// Class fields structure
struct _jc_gnu_xml_util_DoParse$fields_struct {
	struct _jc_org_xml_sax_SAXParseException$object	*fatal;
	jint	errorCount;
	jint	fatalCount;
};
extern _jc_gnu_xml_util_DoParse$fields_struct _jc_gnu_xml_util_DoParse$class_fields;

// Constructors
extern void _jc_gnu_xml_util_DoParse$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_DoParse$object *) _JC_JCNI_ATTR;

// Static methods
extern jint _jc_gnu_xml_util_DoParse$method$access__240$2268a8f72fbb4e6f(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_DoParse$method$access__241$c3d4e057b6cf95fa(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_DoParse$method$access__242$0654588957338362(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_util_DoParse$method$access__243$0b9a6e8ac62e1506(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_DoParse$method$access__244$18c3f443722fc029(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_org_xml_sax_SAXParseException$object *_jc_gnu_xml_util_DoParse$method$access__245$0e6a98ae54f6c356(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_DoParse$method$access__246$a0c66610e253eb4e(_jc_env *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_util_DoParse$method$hasValidator$3b7ba21255c43099(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_DoParse$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_util_DoParse$method$printParseException$c8b5297bca28458c(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_org_xml_sax_SAXParseException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_util_DoParse$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_DoParse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_DoParse$vmethods	gnu_xml_util_DoParse;
};

// Vtype
struct _jc_gnu_xml_util_DoParse$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_DoParse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_DoParse$refs {
    _jc_gnu_xml_util_DoParse$sub_refs	gnu_xml_util_DoParse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_DoParse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_DoParse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_DoParse$sub_nonrefs	gnu_xml_util_DoParse;
};

// Object instance structure
struct _jc_gnu_xml_util_DoParse$object {
	_jc_gnu_xml_util_DoParse$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_DoParse$vtype	*vtype;
	_jc_gnu_xml_util_DoParse$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_DoParse$vtype _jc_gnu_xml_util_DoParse$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_DoParse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_DoParse$class_object;

#endif	/* _JC_gnu_xml_util_DoParse_H_ */
